#
# spec file for package mingw32-winpthreads
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mingw32-winpthreads
Version:        12.0.0
Release:        2.1
Summary:        A pthreads implementation for Windows
License:        BSD-3-Clause AND MIT
Group:          Development/Libraries/C and C++
URL:            http://mingw-w64.sf.net/
Source:         http://downloads.sf.net/mingw-w64/mingw-w64-v%version.tar.bz2
Source9:        %name-rpmlintrc
BuildRequires:  mingw32-cross-gcc-bootstrap
BuildRequires:  mingw32-cross-pkg-config
BuildRequires:  mingw32-filesystem
BuildRequires:  mingw32-runtime
BuildRequires:  xz
%_mingw32_package_header_debug
BuildArch:      noarch
#!BuildIgnore:  post-build-checks

%description
mingw-w64's implementation of POSIX threads for Windows.

%package -n mingw32-libwinpthread1
Summary:        A pthreads implementation for Windows
Group:          System/Libraries
Obsoletes:      mingw32-winpthreads

%description -n mingw32-libwinpthread1
mingw-w64's implementation of POSIX threads for Windows.

%package devel
Summary:        Development files for mingw32-winpthreads
Group:          Development/Libraries/C and C++
Requires:       mingw32-libwinpthread1 = %version
Provides:       mingw32-unistd-pthread-devel
Obsoletes:      mingw32-headers-dummy-pthread
Conflicts:      mingw32-headers-dummy-pthread
Conflicts:      otherproviders(mingw32-unistd-pthread-devel)

%description devel
mingw-w64's implementation of POSIX threads for Windows.

%_mingw32_debug_package

%prep
%autosetup -p1 -n mingw-w64-v%version/mingw-w64-libraries/winpthreads

%build
# The build is trying to link with libpthread.a but it has no need
# of any symbol from there, so just create a fake library and use it.
mkdir fakelib
pushd fakelib
touch empty.c
%_mingw32_cc -c empty.c
%_mingw32_ar rsc libpthread.a empty.o
popd
# No ssp support in gcc-cross-bootstrap
# Hence we use dedicated LDFLAGS (without -fstack-protector)
%_mingw32_configure \
	--enable-static \
	--enable-shared \
    LDFLAGS="%_mingw32_ldflags_bootstrap"
%make_build

%install
%make_install

%files -n mingw32-libwinpthread1
%_mingw32_bindir/libwinpthread-1.dll

%files devel
%_mingw32_includedir/
%_mingw32_libdir/

%changelog
* Wed Aug 28 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 12
  * Version bump to synchronize with mingw64-runtime
* Fri Nov  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 11.0.1
  * crt: Fix .seh_handler directives for ARM
* Mon Jun 27 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 10
  * New msvcrt10, 20, 40, 70 and 71 import libraries.
* Wed Sep 22 2021 Jan Engelhardt <jengelh@inai.de>
- Add arch-independent-package-contains-binary-or-object
  to rpmlintrc
* Sat Jul  3 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 9.0.0
  * unspecified winpthreads fixes
* Wed Mar 17 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to new upstream release 8.0.0
  * Always define `__USE_MINGW_ANSI_STDIO` to zero
  * Remove unused dwFlags variable in sched.c
  * Don't call SetThreadContext in winstore builds
  * Do not call GetHandleInformation in winstore build
  * Simplify the handle validity in pthread_check()
  * Always return 0 in pthread_check() if the thread ended is 0
  * Do not use the XXXExceptionHandler API in winstore builds
  * Simplify the USE_VEH_FOR_MSC_SETTHREADNAME check
* Mon Nov 25 2019 Ralf Habacker <ralf.habacker@freenet.de>
- Use macro _mingw64_ldflags_bootstrap from mingw64-filesystem package
  for setting LDFLAGS to keep common settings in one place
* Mon Nov 25 2019 Ismail Dönmez <idonmez@suse.com>
- Disable stack-protector because we don't have ssp support
  in mingw64-cross-gcc-bootstrap (yet).
* Sat Nov 23 2019 Ismail Dönmez <idonmez@suse.com>
- Update to new upstream release 7.0.0
  * No changelog entries specific to winpthreads found.
* Wed Oct 17 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 6.0.0
  * No changelog entries specific to winpthreads found.
* Tue Nov 21 2017 idonmez@suse.com
- Update to version 5.0.3
- Drop gcc7.patch, fixed upstream.
* Tue Mar 28 2017 idonmez@suse.com
- Update to version 5.0.2
  * Fix some crashes in due to misaligned memory access when
    used with some SSE instructions.
- Drop memleak.patch, fixed upstream.
* Sat Jan 14 2017 idonmez@suse.com
- Update to version 5.0.1
* Wed Mar 23 2016 jengelh@inai.de
- Update to new upstream release 5.0~rc1
  * Winpthreads performance improvements
  * ARM, gcc-5 support
* Fri Sep  4 2015 idonmez@suse.com
- Update to version 4.0.4
  * Major speed improvements to mutex & spinlock implementation
* Fri May 29 2015 idonmez@suse.com
- Enable static libraries
* Wed Mar 25 2015 jengelh@inai.de
- Update to winpthreads from mingw-w64-4.0.1
  * Reentrant time functions localtime_r, gmtime_r, etc. are removed
  from pthread.h and are now available through time.h ONLY.
* Mon Jul 14 2014 jengelh@inai.de
- Implement shlib package naming guidelines
* Thu Jun 19 2014 jw@owncloud.com
- BuildRequires: mingw32-runtime
  Linker fails miserably without.
* Mon Feb  3 2014 jengelh@inai.de
- Initial package (version 3.1.0) for build.opensuse.org
